Data containing the abundance of 17 species expressed in spectral counts. Data generated from an Orbitrap Fusion Lumos Tribrid Mass Spectrometer. The dataset contains the metaproteomes from three extraction methods: i) "Q" for Qiagen, ii) "FW" for fecal waters, and iii) "Q_FW" for the mixture of Qiagen and fecal waters. Data generated in the context of the project Microbiome Rapid Access (Universit<U+00E9> Paris-Saclay).
data(species_fw)A list of four elements defined as "spectral_count_object" with taxonomic annotation generated with the function "crumble_taxonomy"
dataframe with 9 samples containing 17 especies with abundance expressed as spectral counts
information related to the 9 samples from the experiment
information related to each of the 1557 identified peptides
character indicating the type of object